ParameterItem — pyqtgraph 0.11.0rc0 documentation

# ParameterItem

class `pyqtgraph.parametertree.` `ParameterItem`(param, depth=0)

  Abstract ParameterTree item. Used to represent the state of a Parameter from within a ParameterTree.

  - Sets first column of item to name

  - generates context menu if item is renamable or removable

  - handles child added / removed events

  - provides virtual functions for handling changes from parameter

  For more ParameterItem types, see ParameterTree.parameterTypes module.

  `__init__`(param, depth=0)

    Initialize self. See help(type(self)) for accurate signature.

  `columnChangedEvent`(col)

    Called when the text in a column has been edited (or otherwise changed). By default, we only use changes to column 0 to rename the parameter.

  `defaultChanged`(param, default)

    Called when the parameter’s default value has changed

  `focusNext`(forward=True)

    Give focus to the next (or previous) focusable item in the parameter tree

  `isFocusable`()

    Return True if this item should be included in the tab-focus order

  `limitsChanged`(param, limits)

    Called when the parameter’s limits have changed

  `optsChanged`(param, opts)

    Called when any options are changed that are not name, value, default, or limits

  `selected`(sel)

    Called when this item has been selected (sel=True) OR deselected (sel=False)

  `setFocus`()

    Give input focus to this item. Can be reimplemented to display editor widgets, etc.

  `treeWidgetChanged`()

    Called when this item is added or removed from a tree. Expansion, visibility, and column widgets must all be configured AFTER the item is added to a tree, not during __init__.